Module transfer

Module transfer 

Functions

scp_pull
Copy a remote file to the local machine via SFTP.
scp_push
Copy a local file to a remote host via SFTP.
sftp_ls
List files at a path on a remote host.
sftp_read
Read a remote file’s contents without copying it locally.