Module auth

Module auth 

Enums

AuthError

Functions

derive_key_pair
Derive an SSH key pair for a given identity label.
derive_public_key_bytes
Derive the public key bytes for a label (for fingerprint display, authorized_keys export).
public_key_fingerprint
Compute a hex fingerprint of the public key for display.