Shuttle’s implementation of std::sync.
Modules
Structs
- Arc
- A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
- Barrier
- A barrier enables multiple threads to synchronize the beginning of some computation.
- Barrier
Wait Result - A
BarrierWaitResultis returned byBarrier::wait()when all threads in theBarrierhave rendezvoused. - Condvar
- A
Condvarrepresents the ability to block a thread such that it consumes no CPU time while waiting for an event to occur. - Mutex
- A mutex, the same as
std::sync::Mutex. - Mutex
Guard - A mutex guard, the same as
std::sync::MutexGuard. - Once
- A synchronization primitive which can be used to run a one-time global initialization. Useful
for one-time initialization for FFI or related functionality. This type can only be constructed
with
Once::new(). - Once
State - State yielded to
Once::call_once_force()’s closure parameter. The state can be used to query the poison status of theOnce. - RwLock
- A reader-writer lock, the same as
std::sync::RwLock. - RwLock
Read Guard - RAII structure used to release the shared read access of a
RwLockwhen dropped. - RwLock
Write Guard - RAII structure used to release the exclusive write access of a
RwLockwhen dropped. - Wait
Timeout Result - A type indicating whether a timed wait on a condition variable returned due to a time out or not.
- Weak
Weakis a version ofArcthat holds a non-owning reference to the managed allocation.